@@ -1,4 +1,4 @@
-#' Glimpse contrasts in dataframe
+#' Get quick summary of contrasts in dataframe
 #'
 #' Uses the same syntax as [enlist_contrasts()] and
 #' [set_contrasts()]. Returns a summary table of the contrasts you've set. If
@@ -27,6 +27,9 @@
 #' @param minimal Logical, default TRUE, whether to omit the orthogonal,
 #'   centered, dropped_trends, and explicitly_set columns from the output table
 #' @param verbose Logical, defaults to TRUE, whether messages should be printed
+#' @param .droplevels Logical, defaults to TRUE, whether missing levels from
+#' existing factor columns should be dropped before applying new contrasts. See
+#' \code{Options("contrastable.droplevels")}
 #'
 #' @seealso [enlist_contrasts()] [set_contrasts()]
 #' @return A dataframe if return.list is FALSE, a list with a dataframe and list
@@ -48,7 +51,8 @@ glimpse_contrasts <- function(model_data,
                               add_namespace = FALSE,
                               show_one_level_factors = FALSE,
                               minimal = TRUE,
-                              verbose = getOption("contrastable.verbose")) {
+                              verbose = getOption("contrastable.verbose"),
+                              .droplevels = getOption("contrastable.droplevels")) {
   formulas <- purrr::list_flatten(rlang::dots_list(...))
 
   # Get symbols passed to ... and model_data for .warn_if_mismatched_contrasts
@@ -93,7 +97,7 @@ glimpse_contrasts <- function(model_data,
 
   # We do need to compute the contrast matrices so we can get information
   # about orthogonality, centering, etc.
-  contrast_list <- enlist_contrasts(model_data, ..., verbose = FALSE)
+  contrast_list <- enlist_contrasts(model_data, ..., verbose = FALSE, .droplevels = .droplevels)
 
   # The formulas need to be expanded to extract the parameters correctly,
   # but we still need the unexpanded formulas provided by the user so we
@@ -203,15 +207,14 @@ glimpse_contrasts <- function(model_data,
   glimpse
 }
 
-#' Lookup namespace of contrast scheme function
+#' Look up namespace of contrast scheme function
 #'
 #' Given the name of a contrast scheme (ie the function name that creates
-#' the contrast matrix), lookup which namespace it belongs to and add it
-#' to the string. Used to report which packages are used in the glimpse table,
-#' e.g., stats, contrastable, bayesTestR
+#' the contrast matrix), look up which namespace it belongs to and add it
+#' to the string.
 #'
 #' @param scheme_names Character vector
-#'
+#' @noRd
 #' @return character vector of updated function names with namespaces
 .add_namespace <- function(scheme_names) {
   vapply(scheme_names,
@@ -431,7 +434,7 @@ glimpse_contrasts <- function(model_data,
 #' @param which_ordered Which of the factors are ordered
 #' @param schemes_to_use Character vector of schemes, if any don't match the
 #' default for a factor, it will be replaced wtih ??? in th eoutput
-#'
+#' @noRd
 #' @return Warns if non default contrasts are set, returns schemes_to_use with
 #' modifications if necessary
 .warn_if_nondefault <- function(contrast_list,
@@ -630,7 +633,7 @@ glimpse_contrasts <- function(model_data,
 #' @param what Which parameter to retrieve
 #' @param list_params List of params, see [.make_parameters()]
 #' @param formulas Formulas used to set contrasts
-#'
+#' @noRd
 #' @return Requested value for each parameter as a string
 .get_from_params <- function(what, list_params, formulas) {
   stopifnot(what %in% names(list_params[[1]]))
